@@ -1,4 +1,4 @@
-backtransform <- function(x, transform) {
+backtransform <- function(x, transform, draws = NULL) {
     # transform can be a function or a named list of length 1 with a function, but could be NULL
     if (!is.function(transform)) {
         if (is.null(transform[[1]])) {
@@ -11,14 +11,13 @@ backtransform <- function(x, transform) {
     checkmate::assert_data_frame(x)
     checkmate::assert_function(transform)
     cols <- intersect(colnames(x), c("estimate", "conf.low", "conf.high"))
-    draws <- attr(x, "posterior_draws")
 
     if (!is.null(draws)) {
         dim_pre <- dim(draws)
         draws <- transform(draws)
         dim_post <- dim(draws)
         if (!identical(dim_pre, dim_post)) {
-            insight::format_error(
+            stop_sprintf(
                 "The `transform` function must return an object of the same class as its input: a matrix input must return a matrix of the same size, and a vector input must return a vector of the same length."
             )
         }
