@@ -4,9 +4,11 @@ get_predict.MCMCglmm <- function(
     model,
     newdata,
     type = "response",
+    mfx = NULL,
+    newparams = NULL,
     ndraws = 1000,
-    ...
-) {
+    se.fit = NULL,
+    ...) {
     ndraws_mod <- nrow(model$VCV)
     if (ndraws < ndraws_mod) {
         idx <- sample.int(ndraws_mod, ndraws)
@@ -22,10 +24,8 @@ get_predict.MCMCglmm <- function(
         function(i) stats::predict(model, newdata = nd, it = i, ...)
     )
     draws <- do.call("cbind", draws)
-    out <- data.frame(
-        rowid = seq_len(nrow(nd)),
-        estimate = apply(draws, MARGIN = 1, FUN = stats::median)
-    )
+    out <- data.table(estimate = apply(draws, MARGIN = 1, FUN = stats::median))
+    out <- add_rowid(out, newdata)
     attr(out, "posterior_draws") <- draws
     return(out)
 }
@@ -35,7 +35,7 @@ get_predict.MCMCglmm <- function(
 #' @export
 get_vcov.MCMCglmm <- function(model, vcov = NULL, ...) {
     if (!is.null(vcov) && !is.logical(vcov)) {
-        insight::format_warning(
+        warn_sprintf(
             "The `vcov` argument is not supported for models of this class."
         )
     }
