@@ -11,19 +11,10 @@ get_predict.bart <- function(model, newdata = NULL, ...) {
     )
     p <- do.call(stats::predict, args)
     p_med <- collapse::fmedian(p)
-    if ("rowid" %in% colnames(newdata) && nrow(newdata) == length(p_med)) {
-        out <- data.frame(
-            rowid = newdata$rowid,
-            group = "main_marginaleffect",
-            estimate = p_med
-        )
-    } else {
-        out <- data.frame(
-            rowid = seq_along(length(p_med)),
-            group = "main_marginaleffect",
-            estimate = p_med
-        )
-    }
+    out <- data.table(
+        group = "main_marginaleffect",
+        estimate = p_med)
+    out <- add_rowid(out, newdata)
     attr(out, "posterior_draws") <- t(p)
     return(out)
 }
@@ -32,7 +23,7 @@ get_predict.bart <- function(model, newdata = NULL, ...) {
 #' @include sanity_model.R
 #' @rdname sanitize_model_specific
 #' @export
-sanitize_model_specific.bart <- function(model, ...) {
+sanitize_model_specific.bart <- function(model, calling_function, ...) {
     insight::check_if_installed("collapse", minimum_version = "1.9.0")
     if (
         !isTRUE(
@@ -40,7 +31,11 @@ sanitize_model_specific.bart <- function(model, ...) {
         )
     ) {
         msg <- "`marginaleffects` only supports models estimated using the formula interface in `bart2()` function, not the matrix input in `bart()`."
-        insight::format_error(msg)
+        stop_sprintf(msg)
+    }
+    if (calling_function == "hypotheses") {
+        msg <- "`marginaleffects` does not support hypothesis tests for models of class `bart`."
+        stop_sprintf(msg)
     }
     return(model)
 }
@@ -50,7 +45,7 @@ sanitize_model_specific.bart <- function(model, ...) {
 #' @export
 get_vcov.bart <- function(model, vcov = NULL, ...) {
     if (!is.null(vcov) && !is.logical(vcov)) {
-        insight::format_warning(
+        warn_sprintf(
             "The `vcov` argument is not supported for models of this class."
         )
     }
