@@ -12,8 +12,8 @@ get_predict.rlmerMod <- function(
     model,
     newdata = insight::get_data(model),
     type = "response",
-    ...
-) {
+    mfx = NULL,
+    ...) {
     args <- list(...)
     # some predict methods raise warnings on unused arguments
     unused <- c(
@@ -27,14 +27,14 @@ get_predict.rlmerMod <- function(
         "return_format",
         "vcov",
         "eps",
-        "modeldata"
+        "modeldata",
+        "marginaleffects",
+        "mfx"
     )
     args <- args[setdiff(names(args), unused)]
     args[["object"]] <- model
     args[["newdata"]] <- newdata
-    out <- data.frame(
-        rowid = seq_len(nrow(newdata)),
-        estimate = do.call("predict", args)
-    )
+    out <- data.table(estimate = do.call("predict", args))
+    out <- add_rowid(out, newdata)
     return(out)
 }
