@@ -302,40 +302,154 @@ predictions <- function(
     # pre-building the model matrix can speed up repeated predictions
     mfx@newdata <- add_model_matrix_attribute(mfx)
 
-    # main estimation
-    args <- list(
-        mfx = mfx,
-        type = if (link_to_response) "link" else mfx@type,
-        hypothesis = mfx@hypothesis,
-        by = by,
-        byfun = byfun
-    )
+    # Try autodiff early exit
+    autodiff_result <- NULL
+    if (isTRUE(settings_get("autodiff")) && !isFALSE(vcov)) {
+        # Get vcov matrix first
+        mfx@vcov_type <- get_vcov_label(vcov)
+        mfx@vcov_model <- get_vcov(mfx@model, vcov = vcov, type = if (link_to_response) "link" else mfx@type, ...)
 
-    args <- utils::modifyList(args, dots)
-    tmp <- do.call(get_predictions, args)
-
-    # hypothesis formula names are attached in by() in get_predictions()
-    mfx@variable_names_by <- unique(c(
-        mfx@variable_names_by, 
-        attr(tmp, "hypothesis_function_by")))
-
-    # two cases when tmp is a data.frame
-    # get_predict gets us rowid with the original rows
-    if (inherits(tmp, "data.frame")) {
-        setnames(
-            tmp,
-            old = c("Predicted", "SE", "CI_low", "CI_high"),
-            new = c("estimate", "std.error", "conf.low", "conf.high"),
-            skip_absent = TRUE
-        )
-    } else {
-        tmp <- data.frame(mfx@newdata$rowid, mfx@type, tmp)
-        colnames(tmp) <- c("rowid", "estimate")
-        if ("rowidcf" %in% colnames(mfx@newdata)) {
-            tmp[["rowidcf"]] <- mfx@newdata[["rowidcf"]]
+        if (isTRUE(checkmate::check_matrix(mfx@vcov_model))) {
+            # Filter out padding rows before autodiff when using by=character
+            # Padding is only needed for model.matrix construction, which is already done
+            if (is.character(mfx@by) && "rowid" %in% colnames(mfx@newdata)) {
+                idx <- mfx@newdata$rowid > 0
+                if (!all(idx)) {
+                    # Filter newdata and model matrix
+                    mfx@newdata <- mfx@newdata[idx, , drop = FALSE]
+                    # Also filter the model matrix attribute
+                    MM <- attr(mfx@newdata, "marginaleffects_model_matrix")
+                    if (!is.null(MM)) {
+                        attr(mfx@newdata, "marginaleffects_model_matrix") <- MM[idx, , drop = FALSE]
+                    }
+                }
+            }
+            # Try autodiff
+            autodiff_result <- jax_predictions(
+                mfx = mfx,
+                vcov_matrix = mfx@vcov_model,
+                ...
+            )
         }
     }
 
+    if (!is.null(autodiff_result)) {
+        # SUCCESS: Use autodiff results and skip computation pipeline
+
+        # Build result data.frame
+        if (isFALSE(mfx@by)) {
+            # Row-level results
+            tmp <- data.frame(
+                rowid = mfx@newdata$rowid,
+                type = mfx@type,
+                estimate = autodiff_result$estimate,
+                std.error = autodiff_result$std.error
+            )
+            if ("rowidcf" %in% colnames(mfx@newdata)) {
+                tmp[["rowidcf"]] <- mfx@newdata[["rowidcf"]]
+            }
+            # Unpad: remove padding rows added for missing factor levels
+            tmp <- unpad(tmp, draws = NULL)$out
+        } else {
+            # Aggregated results (by=TRUE or by=character)
+            tmp <- data.frame(
+                type = mfx@type,
+                estimate = autodiff_result$estimate,
+                std.error = autodiff_result$std.error
+            )
+
+            # Add grouping columns for by=character
+            if (is.character(mfx@by)) {
+                # Extract unique group combinations
+                bycols <- mfx@by
+                if (inherits(mfx@newdata, "data.table")) {
+                    group_data <- unique(mfx@newdata[, ..bycols])
+                    data.table::setorderv(group_data, bycols)
+                    group_data <- as.data.frame(group_data)
+                } else {
+                    group_data <- unique(mfx@newdata[, bycols, drop = FALSE])
+                    if (nrow(group_data) > 1) {
+                        ord <- do.call(order, group_data)
+                        group_data <- group_data[ord, , drop = FALSE]
+                    }
+                }
+                rownames(group_data) <- NULL
+                tmp <- cbind(group_data, tmp)
+            }
+        }
+
+        # Store jacobian
+        mfx@jacobian <- autodiff_result$jacobian
+
+    } else {
+        # FALLBACK: Use standard computation pipeline
+
+        # main estimation
+        args <- list(
+            mfx = mfx,
+            type = if (link_to_response) "link" else mfx@type,
+            hypothesis = mfx@hypothesis,
+            by = by,
+            byfun = byfun
+        )
+
+        args <- utils::modifyList(args, dots)
+        tmp <- do.call(get_predictions, args)
+
+        # hypothesis formula names are attached in by() in get_predictions()
+        mfx@variable_names_by <- unique(c(
+            mfx@variable_names_by,
+            attr(tmp, "hypothesis_function_by")))
+
+        # two cases when tmp is a data.frame
+        # get_predict gets us rowid with the original rows
+        if (inherits(tmp, "data.frame")) {
+            setnames(
+                tmp,
+                old = c("Predicted", "SE", "CI_low", "CI_high"),
+                new = c("estimate", "std.error", "conf.low", "conf.high"),
+                skip_absent = TRUE
+            )
+        } else {
+            tmp <- data.frame(mfx@newdata$rowid, mfx@type, tmp)
+            colnames(tmp) <- c("rowid", "estimate")
+            if ("rowidcf" %in% colnames(mfx@newdata)) {
+                tmp[["rowidcf"]] <- mfx@newdata[["rowidcf"]]
+            }
+        }
+
+        # bayesian posterior draws
+        mfx@draws <- attr(tmp, "posterior_draws")
+
+        if (!isFALSE(vcov)) {
+            mfx@vcov_type <- get_vcov_label(vcov)
+            mfx@vcov_model <- get_vcov(mfx@model, vcov = vcov, type = mfx@type, ...)
+
+            # Delta method for standard errors
+            if (!"std.error" %in% colnames(tmp) && is.null(mfx@draws) && isTRUE(checkmate::check_matrix(mfx@vcov_model))) {
+                fun <- function(...) {
+                    get_predictions(..., verbose = FALSE)$estimate
+                }
+                args <- list(
+                    mfx = mfx,
+                    model_perturbed = mfx@model,
+                    vcov = mfx@vcov_model,
+                    type = if (link_to_response) "link" else mfx@type,
+                    FUN = fun,
+                    hypothesis = mfx@hypothesis
+                )
+                args <- utils::modifyList(args, dots)
+                se <- do.call(get_se_delta, args)
+                if (is.numeric(se) && length(se) == nrow(tmp)) {
+                    mfx@jacobian <- attr(se, "jacobian")
+                    tmp[["std.error"]] <- as.vector(se) # drop attribute
+                }
+            }
+        }
+    }
+
+    # Common path for both autodiff and fallback
+
     # degrees of freedom - use unpadded newdata
     # Temporarily replace newdata with unpadded version for df calculation
     original_newdata <- mfx@newdata
@@ -353,35 +467,8 @@ predictions <- function(
         tmp$df <- mfx@df
     }
 
-    # bayesian posterior draws
-    mfx@draws <- attr(tmp, "posterior_draws")
-
-    if (!isFALSE(vcov)) {
-        mfx@vcov_type <- get_vcov_label(vcov)
-        mfx@vcov_model <- get_vcov(mfx@model, vcov = vcov, type = mfx@type, ...)
-
-        # Delta method for standard errors
-        if (!"std.error" %in% colnames(tmp) && is.null(mfx@draws) && isTRUE(checkmate::check_matrix(mfx@vcov_model))) {
-            fun <- function(...) {
-                get_predictions(..., verbose = FALSE)$estimate
-            }
-            args <- list(
-                mfx = mfx,
-                model_perturbed = mfx@model,
-                vcov = mfx@vcov_model,
-                type = if (link_to_response) "link" else mfx@type,
-                FUN = fun,
-                hypothesis = mfx@hypothesis
-            )
-            args <- utils::modifyList(args, dots)
-            se <- do.call(get_se_delta, args)
-            if (is.numeric(se) && length(se) == nrow(tmp)) {
-                mfx@jacobian <- attr(se, "jacobian")
-                tmp[["std.error"]] <- as.vector(se) # drop attribute
-            }
-        }
-
-        # Confidence intervals
+    # Confidence intervals (autodiff already has std.error)
+    if (!isFALSE(vcov) && ("std.error" %in% colnames(tmp) || !is.null(mfx@draws))) {
         tmp <- get_ci(tmp, mfx)
     }
 
