@@ -27,12 +27,13 @@
 .onLoad <- function(lib, pkg) {
     backports::import(pkg)
     if (isNamespaceLoaded("reticulate")) {
-        py_require_marginal_effects_ad()
+        py_require_marginaleffects()
     } else {
-        setHook(packageEvent("reticulate", "onLoad"), py_require_marginal_effects_ad)
+        setHook(packageEvent("reticulate", "onLoad"), py_require_marginaleffects)
     }
 }
 
-py_require_marginal_effects_ad <- function(...) {
-    reticulate::py_require("marginaleffectsAD")
+py_require_marginaleffects <- function(...) {
+    reticulate::py_require("marginaleffects")
+    reticulate::py_require("jax")
 }
